#!/usr/bin/env node
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import inquirer from "inquirer";
import path from "path";
import * as fs from "fs";
import { fileURLToPath } from "url";
import { installUmbraco } from "./umbraco/installUmbraco.js";
import { copyFolderSync, executeInSeries } from "./utils/utils.js";
import { setupFrontend } from "./frontend/setupFrontend.js";
import { initializeGitRepo } from "./generic/initializeGitRepo.js";
import { installDotNetSDK } from "./umbraco/installDotNetSDK.js";
import { createSolutionFile } from "./umbraco/createSolutionFile.js";
import { setupUmbracoTemplate } from "./umbraco/setupUmbracoTemplate.js";
const setupProject = () => __awaiter(void 0, void 0, void 0, function* () {
    try {
        const __filename = fileURLToPath(import.meta.url);
        const __dirname = path.dirname(__filename);
        copyFolderSync(path.join(__dirname, "..", "template"), path.join(__dirname, "..", "dist", "template"));
        process.stdout.write("\nWelcome to the project setup wizard!\n");
        const answers = yield inquirer.prompt([
            {
                type: "input",
                name: "projectName",
                message: "Enter the project name:",
                validate: (input) => (input ? true : "Project name cannot be empty"),
            },
            {
                type: "confirm",
                name: "useUmbraco",
                message: "Do you want to set up the project with Umbraco?",
                default: true,
            },
            {
                type: "list",
                name: "versionChoice",
                message: "Choose the Umbraco version:",
                choices: ["Latest", "Other"],
                when: (answers) => answers.useUmbraco,
            },
            {
                type: "list",
                name: "umbracoVersion",
                message: "Choose the Umbraco version:",
                choices: ["13.5.1", "12.3.10", "11.5.0", "10.8.6", "Choose"],
                when: (answers) => answers.versionChoice === "Other",
            },
            {
                type: "input",
                name: "ChooseUmbracoVersion",
                message: "Write the Umbraco version:",
                when: (answers) => answers.umbracoVersion === "Choose",
                validate: (input) => (input ? true : "Umbraco version cannot be empty"),
            },
            {
                type: "list",
                name: "frontendTech",
                message: "Choose the frontend technology:",
                choices: ["Gulp", "Vue", "React"],
            },
            {
                type: "list",
                name: "frontendTechFramework",
                message: "Do you want to use Next.js or React?",
                when: (answers) => answers.frontendTech === "React",
                choices: ["React", "Next.js"],
                default: "React",
            },
            {
                type: "list",
                name: "frontendTechFramework",
                message: "Do you want to use Nuxt.js or standard Vue?",
                when: (answers) => answers.frontendTech === "Vue",
                choices: ["Vue", "Nuxt.js"],
                default: "Vue",
            },
            {
                type: "input",
                name: "gitRepo",
                message: "Enter the Git repository URL: (Optional)",
            },
        ]);
        const umbracoVersion = answers.versionChoice === "Other"
            ? answers.umbracoVersion === "Choose"
                ? answers.ChooseUmbracoVersion
                : answers.umbracoVersion
            : answers.versionChoice;
        answers.frontendTech = !answers.frontendTechFramework
            ? answers.frontendTech
            : answers.frontendTechFramework;
        const projectDir = path.join(process.cwd(), answers.projectName);
        const umbracoDir = path.join(projectDir, answers.projectName);
        if (!fs.existsSync(projectDir)) {
            fs.mkdirSync(projectDir);
        }
        const tasks = [
            () => setupFrontend(projectDir, answers),
            () => initializeGitRepo(projectDir, answers),
        ];
        if (answers.useUmbraco) {
            tasks.unshift(() => installDotNetSDK(), () => installUmbraco(umbracoDir, umbracoVersion), () => createSolutionFile(projectDir, umbracoDir, answers), () => setupUmbracoTemplate(umbracoDir));
        }
        yield executeInSeries(tasks);
    }
    catch (err) {
        console.error("Error setting up project:", err);
    }
});
setupProject();
